@@ -33,8 +33,6 @@
 
 #include "asterisk.h"
 
-ASTERISK_REGISTER_FILE()
-
 #include <math.h>
 #include <sys/time.h>
 
@@ -363,7 +361,6 @@ static int disa_exec(struct ast_channel *chan, const char *data)
 
 	if (k == 3) {
 		int recheck = 0;
-		struct ast_app *app_reset_cdr;
 
 		if (!ast_exists_extension(chan, args.context, exten, 1,
 			S_COR(ast_channel_caller(chan)->id.number.valid, ast_channel_caller(chan)->id.number.str, NULL))) {
@@ -388,10 +385,7 @@ static int disa_exec(struct ast_channel *chan, const char *data)
 				ast_channel_unlock(chan);
 			}
 
-			app_reset_cdr = pbx_findapp("ResetCDR");
-			if (app_reset_cdr) {
-				pbx_exec(chan, app_reset_cdr, special_noanswer ? "" : "e");
-			} else {
+			if (ast_pbx_exec_application(chan, "ResetCDR", special_noanswer ? "" : "e")) {
 				ast_log(AST_LOG_NOTICE, "ResetCDR application not found; CDR will not be reset\n");
 			}
 			ast_explicit_goto(chan, args.context, exten, 1);
