@@ -42,7 +42,8 @@ AST_THREADSTORAGE_EXTERNAL(ast_str_thread_global_buf);
 /* IVR stuff */
 
 /*! \brief Callback function for IVR
-    \return returns 0 on completion, -1 on hangup or digit if interrupted
+    \retval 0 on completion.
+    \retval -1 on hangup or digit if interrupted.
   */
 typedef int (ast_ivr_callback)(struct ast_channel *chan, char *option, void *cbdata);
 
@@ -56,7 +57,7 @@ typedef enum {
 	AST_ACTION_MENU,	/*!< adata is a pointer to an ast_ivr_menu */
 	AST_ACTION_REPEAT,	/*!< adata is max # of repeats, cast to a pointer */
 	AST_ACTION_RESTART,	/*!< adata is like repeat, but resets repeats to 0 */
-	AST_ACTION_TRANSFER,	/*!< adata is a string with exten\verbatim[@context]\endverbatim */
+	AST_ACTION_TRANSFER,	/*!< adata is a string with exten[\@context] */
 	AST_ACTION_WAITOPTION,	/*!< adata is a timeout, or 0 for defaults */
 	AST_ACTION_NOOP,	/*!< adata is unused */
 	AST_ACTION_BACKLIST,	/*!< adata is list of files separated by ; allows interruption */
@@ -94,9 +95,7 @@ struct ast_vm_recording_data {
 		AST_STRING_FIELD(folder);
 		AST_STRING_FIELD(recording_file);
 		AST_STRING_FIELD(recording_ext);
-
 		AST_STRING_FIELD(call_context);
-		AST_STRING_FIELD(call_macrocontext);
 		AST_STRING_FIELD(call_extension);
 		AST_STRING_FIELD(call_callerchan);
 		AST_STRING_FIELD(call_callerid);
@@ -118,9 +117,22 @@ enum ast_timelen {
 };
 
 /*!	\brief Runs an IVR menu
-	\return returns 0 on successful completion, -1 on hangup, or -2 on user error in menu */
+	\retval 0 on successful completion.
+	\retval -1 on hangup.
+	\retval -2 on user error in menu.
+*/
 int ast_ivr_menu_run(struct ast_channel *c, struct ast_ivr_menu *menu, void *cbdata);
 
+enum ast_getdata_result {
+	AST_GETDATA_FAILED = -1,
+	AST_GETDATA_COMPLETE = 0,
+	AST_GETDATA_TIMEOUT = 1,
+	AST_GETDATA_INTERRUPTED = 2,
+	/*! indicates a user terminated empty string rather than an empty string resulting
+	 * from a timeout or other factors */
+	AST_GETDATA_EMPTY_END_TERMINATED = 3,
+};
+
 /*! \brief Plays a stream and gets DTMF data from a channel
  * \param c Which channel one is interacting with
  * \param prompt File to pass to ast_streamfile (the one that you wish to play).
@@ -135,55 +147,28 @@ int ast_ivr_menu_run(struct ast_channel *c, struct ast_ivr_menu *menu, void *cbd
  *  is pressed during playback, it will immediately break out of the message and continue
  *  execution of your code.
  */
-int ast_app_getdata(struct ast_channel *c, const char *prompt, char *s, int maxlen, int timeout);
+enum ast_getdata_result ast_app_getdata(struct ast_channel *c, const char *prompt, char *s, int maxlen, int timeout);
+
+/*! \brief Plays a stream and gets DTMF data from a channel
+ * \param c Which channel one is interacting with
+ * \param prompt File to pass to ast_streamfile (the one that you wish to play).
+ *        It is also valid for this to be multiple files concatenated by "&".
+ *        For example, "file1&file2&file3".
+ * \param s The location where the DTMF data will be stored
+ * \param maxlen Max Length of the data
+ * \param timeout Timeout length waiting for data(in milliseconds).  Set to 0 for standard timeout(six seconds), or -1 for no time out.
+ * \param terminator A string of characters that may be used as terminators to end input. If NULL, "#" will be used.
+ *
+ *  This function was designed for application programmers for situations where they need
+ *  to play a message and then get some DTMF data in response to the message.  If a digit
+ *  is pressed during playback, it will immediately break out of the message and continue
+ *  execution of your code.
+ */
+enum ast_getdata_result ast_app_getdata_terminator(struct ast_channel *c, const char *prompt, char *s, int maxlen, int timeout, char *terminator);
 
 /*! \brief Full version with audiofd and controlfd.  NOTE: returns '2' on ctrlfd available, not '1' like other full functions */
 int ast_app_getdata_full(struct ast_channel *c, const char *prompt, char *s, int maxlen, int timeout, int audiofd, int ctrlfd);
 
-/*!
- * \brief Run a macro on a channel, placing an optional second channel into autoservice.
- * \since 11.0
- *
- * \details
- * This is a shorthand method that makes it very easy to run a
- * macro on any given channel.  It is perfectly reasonable to
- * supply a NULL autoservice_chan here in case there is no
- * channel to place into autoservice.
- *
- * \note Absolutely _NO_ channel locks should be held before calling this function.
- *
- * \param autoservice_chan A channel to place into autoservice while the macro is run
- * \param macro_chan Channel to execute macro on.
- * \param macro_args Macro application argument string.
- *
- * \retval 0 success
- * \retval -1 on error
- */
-int ast_app_exec_macro(struct ast_channel *autoservice_chan, struct ast_channel *macro_chan, const char *macro_args);
-
-/*!
- * \since 1.8
- * \brief Run a macro on a channel, placing an optional second channel into autoservice.
- *
- * \details
- * This is a shorthand method that makes it very easy to run a
- * macro on any given channel.  It is perfectly reasonable to
- * supply a NULL autoservice_chan here in case there is no
- * channel to place into autoservice.
- *
- * \note Absolutely _NO_ channel locks should be held before calling this function.
- *
- * \param autoservice_chan A channel to place into autoservice while the macro is run
- * \param macro_chan Channel to execute macro on.
- * \param macro_name The name of the macro to run.
- * \param macro_args The arguments to pass to the macro.
- *
- * \retval 0 success
- * \retval -1 on error
- */
-int ast_app_run_macro(struct ast_channel *autoservice_chan,
-	struct ast_channel *macro_chan, const char *macro_name, const char *macro_args);
-
 /*!
  * \brief Stack applications callback functions.
  */
@@ -217,7 +202,7 @@ struct ast_app_stack_funcs {
 	 * \details
 	 * Fills in the optional context and exten from the given channel.
 	 *
-	 * \retval New-args Gosub argument string on success.  Must be freed.
+	 * \return New-args Gosub argument string on success.  Must be freed.
 	 * \retval NULL on error.
 	 */
 	const char *(*expand_sub_args)(struct ast_channel *chan, const char *args);
@@ -241,7 +226,7 @@ void ast_install_stack_functions(const struct ast_app_stack_funcs *funcs);
  * \details
  * Fills in the optional context and exten from the given channel.
  *
- * \retval New-args Gosub argument string on success.  Must be freed.
+ * \return New-args Gosub argument string on success.  Must be freed.
  * \retval NULL on error.
  */
 const char *ast_app_expand_sub_args(struct ast_channel *chan, const char *args);
@@ -334,7 +319,7 @@ typedef void (ast_vm_msg_play_cb)(struct ast_channel *chan, const char *playfile
 /*!
  * \brief Determines if the given folder has messages.
  *
- * \param mailboxes Comma or & delimited list of mailboxes (user@context).
+ * \param mailboxes Comma or & delimited list of mailboxes (user\@context).
  *          If no context is found, uses 'default' for the context.
  * \param folder The folder to look in.  Default is INBOX if not provided.
  *
@@ -346,7 +331,7 @@ typedef int (ast_has_voicemail_fn)(const char *mailboxes, const char *folder);
 /*!
  * \brief Gets the number of messages that exist for the mailbox list.
  *
- * \param mailboxes Comma or space delimited list of mailboxes (user@context).
+ * \param mailboxes Comma or space delimited list of mailboxes (user\@context).
  *          If no context is found, uses 'default' for the context.
  * \param newmsgs Where to put the count of new messages. (Can be NULL)
  * \param oldmsgs Where to put the count of old messages. (Can be NULL)
@@ -363,7 +348,7 @@ typedef int (ast_inboxcount_fn)(const char *mailboxes, int *newmsgs, int *oldmsg
 /*!
  * \brief Gets the number of messages that exist for the mailbox list.
  *
- * \param mailboxes Comma or space delimited list of mailboxes (user@context).
+ * \param mailboxes Comma or space delimited list of mailboxes (user\@context).
  *          If no context is found, uses 'default' for the context.
  * \param urgentmsgs Where to put the count of urgent messages. (Can be NULL)
  * \param newmsgs Where to put the count of new messages. (Can be NULL)
@@ -398,7 +383,7 @@ typedef int (ast_messagecount_fn)(const char *mailbox_id, const char *folder);
  * \param mailbox_id The mailbox name.
  *
  * \retval 0 Name played without interruption
- * \retval dtmf ASCII value of the DTMF which interrupted playback.
+ * \return dtmf ASCII value of the DTMF which interrupted playback.
  * \retval -1 Unable to locate mailbox or hangup occurred.
  */
 typedef int (ast_sayname_fn)(struct ast_channel *chan, const char *mailbox_id);
@@ -427,8 +412,8 @@ typedef const char *(ast_vm_index_to_foldername_fn)(int id);
 /*!
  * \brief Create a snapshot of a mailbox which contains information about every msg.
  *
- * \param user The user part of user@context.
- * \param context The context part of user@context.  Must be explicit.
+ * \param user The user part of user\@context.
+ * \param context The context part of user\@context.  Must be explicit.
  * \param folder When not NULL only msgs from the specified folder will be included.
  * \param descending list the msgs in descending order rather than ascending order.
  * \param sort_val What to sort in the snapshot.
@@ -438,7 +423,7 @@ typedef const char *(ast_vm_index_to_foldername_fn)(int id);
  *
  * \note Only used by voicemail unit tests.
  *
- * \retval snapshot on success
+ * \return snapshot on success
  * \retval NULL on failure
  */
 typedef struct ast_vm_mailbox_snapshot *(ast_vm_mailbox_snapshot_create_fn)(const char *user,
@@ -590,9 +575,7 @@ int __ast_vm_register(const struct ast_vm_functions *vm_table, struct ast_module
 /*!
  * \brief Unregister the specified voicemail provider
  *
- * \param The module name of the provider to unregister
- *
- * \return Nothing
+ * \param module_name The module name of the provider to unregister
  */
 void ast_vm_unregister(const char *module_name);
 
@@ -660,9 +643,7 @@ int __ast_vm_greeter_register(const struct ast_vm_greeter_functions *vm_table, s
  * \brief Unregister the specified voicemail greeter provider
  * \since 13.0.0
  *
- * \param The module name of the provider to unregister
- *
- * \return Nothing
+ * \param module_name The module name of the provider to unregister
  */
 void ast_vm_greeter_unregister(const char *module_name);
 
@@ -715,7 +696,8 @@ int ast_app_inboxcount(const char *mailboxes, int *newmsgs, int *oldmsgs);
  * \param[out] urgentmsgs the urgent message count
  * \param[out] newmsgs the new message count
  * \param[out] oldmsgs the old message count
- * \return Returns 0 for success, negative upon error
+ * \retval 0 for success
+ * \retval negative upon error
  * \since 1.6.1
  */
 int ast_app_inboxcount2(const char *mailboxes, int *urgentmsgs, int *newmsgs, int *oldmsgs);
@@ -754,15 +736,16 @@ const char *ast_vm_index_to_foldername(int id);
 /*!
  * \brief Create a snapshot of a mailbox which contains information about every msg.
  *
- * \param mailbox, the mailbox to look for
- * \param context, the context to look for the mailbox in
- * \param folder, OPTIONAL.  When not NULL only msgs from the specified folder will be included.
- * \param descending, list the msgs in descending order rather than ascending order.
- * \param combine_INBOX_and_OLD, When this argument is set, The OLD folder will be represented
+ * \param mailbox the mailbox to look for
+ * \param context the context to look for the mailbox in
+ * \param folder OPTIONAL.  When not NULL only msgs from the specified folder will be included.
+ * \param descending list the msgs in descending order rather than ascending order.
+ * \param sort_val What to sort in the snapshot.
+ * \param combine_INBOX_and_OLD When this argument is set, The OLD folder will be represented
  *        in the INBOX folder of the snapshot. This allows the snapshot to represent the
  *        OLD and INBOX messages in sorted order merged together.
  *
- * \retval snapshot on success
+ * \return snapshot on success
  * \retval NULL on failure
  */
 struct ast_vm_mailbox_snapshot *ast_vm_mailbox_snapshot_create(const char *mailbox,
@@ -923,24 +906,107 @@ void ast_replace_sigchld(void);
 void ast_unreplace_sigchld(void);
 
 /*!
-  \brief Send DTMF to a channel
+ * \brief Send a string of SF digits to a channel
+ *
+ * \param chan    The channel that will receive the SF digits
+ * \param peer    (optional) Peer channel that will be autoserviced while the
+ *                primary channel is receiving SF
+ * \param chan2   A second channel that will simultaneously receive SF digits.
+ *                This option may only be used if is_external is 0.
+ * \param digits  This is a string of characters representing the SF digits
+ *                to be sent to the channel.  Valid characters are
+ *                "0123456789".  Note: You can pass arguments 'f' or
+ *                'F', if you want to Flash the channel (if supported by the
+ *                channel), or 'w' or 'W' to add a wink (if supported by the
+ *                channel).
+ * \param frequency  The frequency to use for signaling. 0 can be specified for
+ *                the default, which is 2600 Hz.
+ * \param is_external 1 if called by a thread that is not the channel's media
+ *                handler thread, 0 if called by the channel's media handler
+ *                thread.
+ *
+ * \retval 0 on success.
+ * \retval -1 on failure or a channel hung up.
+ */
+int ast_sf_stream(struct ast_channel *chan, struct ast_channel *peer, struct ast_channel *chan2, const char *digits, int frequency, int is_external);
 
-  \param chan    The channel that will receive the DTMF frames
-  \param peer    (optional) Peer channel that will be autoserviced while the
-                 primary channel is receiving DTMF
-  \param digits  This is a string of characters representing the DTMF digits
-                 to be sent to the channel.  Valid characters are
-                 "0123456789*#abcdABCD".  Note: You can pass arguments 'f' or
-                 'F', if you want to Flash the channel (if supported by the
-                 channel), or 'w' to add a 500 millisecond pause to the DTMF
-                 sequence.
-  \param between This is the number of milliseconds to wait in between each
-                 DTMF digit.  If zero milliseconds is specified, then the
-                 default value of 100 will be used.
-  \param duration This is the duration that each DTMF digit should have.
-*/
+/*!
+ * \brief Send a string of MF digits to a channel
+ *
+ * \param chan    The channel that will receive the MF digits.
+ * \param peer    (optional) Peer channel that will be autoserviced while the
+ *                primary channel is receiving MF
+ * \param chan2   A second channel that will simultaneously receive MF digits.
+ *                This option may only be used if is_external is 0.
+ * \param digits  This is a string of characters representing the MF digits
+ *                to be sent to the channel.  Valid characters are
+ *                "0123456789*#abcdABCD".  Note: You can pass arguments 'f' or
+ *                'F', if you want to Flash the channel (if supported by the
+ *                channel), or 'w' or 'W' to add a wink (if supported by the
+ *                channel).
+ * \param between This is the number of milliseconds to wait in between each
+ *                MF digit.  If zero milliseconds is specified, then the
+ *                default value of 50 will be used.
+ * \param duration This is the duration that each numeric MF digit should have.
+ *                 Default value is 55.
+ * \param durationkp This is the duration that each KP digit should have. Default
+ *                is 120.
+ * \param durationst This is the duration that each ST, STP, ST2P, or ST3P digit
+ *                should have. Default is 65.
+ * \param is_external 1 if called by a thread that is not the channel's media
+ *                handler thread, 0 if called by the channel's media handler
+ *                thread.
+ *
+ * \retval 0 on success.
+ * \retval -1 on failure or a channel hung up.
+ */
+int ast_mf_stream(struct ast_channel *chan, struct ast_channel *peer, struct ast_channel *chan2, const char *digits,
+	int between, unsigned int duration, unsigned int durationkp, unsigned int durationst, int is_external);
+
+/*!
+ * \brief Send a string of DTMF digits to a channel
+ *
+ * \param chan    The channel that will receive the DTMF frames
+ * \param peer    (optional) Peer channel that will be autoserviced while the
+ *                primary channel is receiving DTMF
+ * \param digits  This is a string of characters representing the DTMF digits
+ *                to be sent to the channel.  Valid characters are
+ *                "0123456789*#abcdABCD".  Note: You can pass arguments 'f' or
+ *                'F', if you want to Flash the channel (if supported by the
+ *                channel), or 'w' to add a 500 millisecond pause to the DTMF
+ *                sequence.
+ * \param between This is the number of milliseconds to wait in between each
+ *                DTMF digit.  If zero milliseconds is specified, then the
+ *                default value of 100 will be used.
+ * \param duration This is the duration that each DTMF digit should have.
+ *
+ * \pre This must only be called by the channel's media handler thread.
+ *
+ * \retval 0 on success.
+ * \retval -1 on failure or a channel hung up.
+ */
 int ast_dtmf_stream(struct ast_channel *chan, struct ast_channel *peer, const char *digits, int between, unsigned int duration);
 
+/*!
+ * \brief Send a string of DTMF digits to a channel from an external thread.
+ *
+ * \param chan    The channel that will receive the DTMF frames
+ * \param digits  This is a string of characters representing the DTMF digits
+ *                to be sent to the channel.  Valid characters are
+ *                "0123456789*#abcdABCD".  Note: You can pass arguments 'f' or
+ *                'F', if you want to Flash the channel (if supported by the
+ *                channel), or 'w' to add a 500 millisecond pause to the DTMF
+ *                sequence.
+ * \param between This is the number of milliseconds to wait in between each
+ *                DTMF digit.  If zero milliseconds is specified, then the
+ *                default value of 100 will be used.
+ * \param duration This is the duration that each DTMF digit should have.
+ *
+ * \pre This must only be called by threads that are not the channel's
+ * media handler thread.
+ */
+void ast_dtmf_stream_external(struct ast_channel *chan, const char *digits, int between, unsigned int duration);
+
 /*! \brief Stream a filename (or file descriptor) as a generator. */
 int ast_linear_stream(struct ast_channel *chan, const char *filename, int fd, int allowoverride);
 
@@ -986,7 +1052,7 @@ int ast_control_tone(struct ast_channel *chan, const char *tone);
  * \param chan
  * \param file filename
  * \param fwd, rev, stop, pause, restart, skipms, offsetms
- * \param cb waitstream callback to invoke when fastforward or rewind occurrs.
+ * \param cb waitstream callback to invoke when fastforward or rewind occurs.
  *
  * Before calling this function, set this to be the number
  * of ms to start from the beginning of the file.  When the function
@@ -1093,16 +1159,6 @@ int ast_play_and_record(struct ast_channel *chan, const char *playfile, const ch
  */
 int ast_play_and_prepend(struct ast_channel *chan, char *playfile, char *recordfile, int maxtime_sec, char *fmt, int *duration, int *sound_duration, int beep, int silencethreshold, int maxsilence_ms);
 
-enum ast_getdata_result {
-	AST_GETDATA_FAILED = -1,
-	AST_GETDATA_COMPLETE = 0,
-	AST_GETDATA_TIMEOUT = 1,
-	AST_GETDATA_INTERRUPTED = 2,
-	/*! indicates a user terminated empty string rather than an empty string resulting
-	 * from a timeout or other factors */
-	AST_GETDATA_EMPTY_END_TERMINATED = 3,
-};
-
 enum AST_LOCK_RESULT {
 	AST_LOCK_SUCCESS = 0,
 	AST_LOCK_TIMEOUT = -1,
@@ -1188,7 +1244,7 @@ int ast_app_group_list_unlock(void);
   ast_app_separate_args() will perform that function before parsing
   the arguments.
  */
-#define AST_DECLARE_APP_ARGS(name, arglist) AST_DEFINE_APP_ARGS_TYPE(, arglist) name = { 0, }
+#define AST_DECLARE_APP_ARGS(name, arglist) AST_DEFINE_APP_ARGS_TYPE(argtype_##name, arglist) name = { 0, }
 
 /*!
   \brief Define a structure type to hold an application's arguments.
@@ -1204,11 +1260,15 @@ int ast_app_group_list_unlock(void);
   \note This defines a structure type, but does not declare an instance
   of the structure. That must be done separately.
  */
+
 #define AST_DEFINE_APP_ARGS_TYPE(type, arglist) \
+	struct __subtype_##type { arglist }; \
 	struct type { \
 		unsigned int argc; \
-		char *argv[0]; \
-		arglist \
+		union { \
+			char *argv[sizeof(struct __subtype_##type) / sizeof(char*)]; \
+			struct { arglist }; \
+		}; \
 	}
 
 /*!
@@ -1357,7 +1417,8 @@ struct ast_app_option {
   \param flags The flag structure to have option flags set
   \param args The array of argument pointers to hold arguments found
   \param optstr The string containing the options to be parsed
-  \return zero for success, non-zero if an error occurs
+  \retval zero for success
+  \retval non-zero if an error occurs
   \sa AST_APP_OPTIONS
  */
 int ast_app_parse_options(const struct ast_app_option *options, struct ast_flags *flags, char **args, char *optstr);
@@ -1368,7 +1429,8 @@ int ast_app_parse_options(const struct ast_app_option *options, struct ast_flags
   \param flags The 64-bit flag structure to have option flags set
   \param args The array of argument pointers to hold arguments found
   \param optstr The string containing the options to be parsed
-  \return zero for success, non-zero if an error occurs
+  \retval zero for success
+  \retval non-zero if an error occurs
   \sa AST_APP_OPTIONS
  */
 int ast_app_parse_options64(const struct ast_app_option *options, struct ast_flags64 *flags, char **args, char *optstr);
@@ -1382,7 +1444,9 @@ int ast_app_parse_options64(const struct ast_app_option *options, struct ast_fla
 void ast_app_options2str64(const struct ast_app_option *options, struct ast_flags64 *flags, char *buf, size_t len);
 
 /*! \brief Present a dialtone and collect a certain length extension.
-    \return Returns 1 on valid extension entered, -1 on hangup, or 0 on invalid extension.
+    \retval 1 if extension exists
+    \retval 0 if extension does not exist
+    \retval -1 on hangup
 \note Note that if 'collect' holds digits already, new digits will be appended, so be sure it's initialized properly */
 int ast_app_dtget(struct ast_channel *chan, const char *context, char *collect, size_t size, int maxlen, int timeout);
 
@@ -1442,203 +1506,9 @@ void ast_safe_fork_cleanup(void);
  */
 int ast_app_parse_timelen(const char *timestr, int *result, enum ast_timelen defunit);
 
-/*!
- * \since 12
- * \brief Publish a MWI state update via stasis
- *
- * \param[in] mailbox The mailbox identifier string.
- * \param[in] context The context this mailbox resides in (NULL or "" if only using mailbox)
- * \param[in] new_msgs The number of new messages in this mailbox
- * \param[in] old_msgs The number of old messages in this mailbox
- *
- * \retval 0 Success
- * \retval -1 Failure
- */
-#define ast_publish_mwi_state(mailbox, context, new_msgs, old_msgs) \
-	ast_publish_mwi_state_full(mailbox, context, new_msgs, old_msgs, NULL, NULL)
-
-/*!
- * \since 12
- * \brief Publish a MWI state update associated with some channel
- *
- * \param[in] mailbox The mailbox identifier string.
- * \param[in] context The context this mailbox resides in (NULL or "" if only using mailbox)
- * \param[in] new_msgs The number of new messages in this mailbox
- * \param[in] old_msgs The number of old messages in this mailbox
- * \param[in] channel_id A unique identifier for a channel associated with this
- * change in mailbox state
- *
- * \retval 0 Success
- * \retval -1 Failure
- */
-#define ast_publish_mwi_state_channel(mailbox, context, new_msgs, old_msgs, channel_id) \
-	ast_publish_mwi_state_full(mailbox, context, new_msgs, old_msgs, channel_id, NULL)
-
-/*!
- * \since 12
- * \brief Publish a MWI state update via stasis with all parameters
- *
- * \param[in] mailbox The mailbox identifier string.
- * \param[in] context The context this mailbox resides in (NULL or "" if only using mailbox)
- * \param[in] new_msgs The number of new messages in this mailbox
- * \param[in] old_msgs The number of old messages in this mailbox
- * \param[in] channel_id A unique identifier for a channel associated with this
- * change in mailbox state
- * \param[in] eid The EID of the server that originally published the message
- *
- * \retval 0 Success
- * \retval -1 Failure
- */
-int ast_publish_mwi_state_full(
-	const char *mailbox,
-	const char *context,
-	int new_msgs,
-	int old_msgs,
-	const char *channel_id,
-	struct ast_eid *eid);
-
-/*!
- * \since 12.2.0
- * \brief Delete MWI state cached by stasis
- *
- * \param[in] mailbox The mailbox identifier string.
- * \param[in] context The context this mailbox resides in (NULL or "" if only using mailbox)
- *
- * \retval 0 Success
- * \retval -1 Failure
- */
-#define ast_delete_mwi_state(mailbox, context) \
-	ast_delete_mwi_state_full(mailbox, context, NULL)
-
-/*!
- * \since 12.2.0
- * \brief Delete MWI state cached by stasis with all parameters
- *
- * \param[in] mailbox The mailbox identifier string.
- * \param[in] context The context this mailbox resides in (NULL or "" if only using mailbox)
- * \param[in] eid The EID of the server that originally published the message
- *
- * \retval 0 Success
- * \retval -1 Failure
- */
-int ast_delete_mwi_state_full(const char *mailbox, const char *context, struct ast_eid *eid);
-
-/*! \addtogroup StasisTopicsAndMessages
- * @{
- */
-
-/*!
- * \brief The structure that contains MWI state
- * \since 12
- */
-struct ast_mwi_state {
-	AST_DECLARE_STRING_FIELDS(
-		AST_STRING_FIELD(uniqueid);  /*!< Unique identifier for this mailbox */
-	);
-	int new_msgs;                    /*!< The current number of new messages for this mailbox */
-	int old_msgs;                    /*!< The current number of old messages for this mailbox */
-	/*! If applicable, a snapshot of the channel that caused this MWI change */
-	struct ast_channel_snapshot *snapshot;
-	struct ast_eid eid;              /*!< The EID of the server where this message originated */
-};
-
-/*!
- * \brief Object that represents an MWI update with some additional application
- * defined data
- */
-struct ast_mwi_blob {
-	struct ast_mwi_state *mwi_state;    /*!< MWI state */
-	struct ast_json *blob;              /*!< JSON blob of data */
-};
-
-/*!
- * \since 12
- * \brief Create a \ref ast_mwi_state object
- *
- * \param[in] mailbox The mailbox identifier string.
- * \param[in] context The context this mailbox resides in (NULL or "" if only using mailbox)
- *
- * \retval \ref ast_mwi_state object on success
- * \retval NULL on error
- */
-struct ast_mwi_state *ast_mwi_create(const char *mailbox, const char *context);
-
-/*!
- * \since 12
- * \brief Creates a \ref ast_mwi_blob message.
- *
- * The \a blob JSON object requires a \c "type" field describing the blob. It
- * should also be treated as immutable and not modified after it is put into the
- * message.
- *
- * \param mwi_state MWI state associated with the update
- * \param message_type The type of message to create
- * \param blob JSON object representing the data.
- * \return \ref ast_mwi_blob message.
- * \return \c NULL on error
- */
-struct stasis_message *ast_mwi_blob_create(struct ast_mwi_state *mwi_state,
-					   struct stasis_message_type *message_type,
-					   struct ast_json *blob);
-
-/*!
- * \brief Get the \ref stasis topic for MWI messages
- * \retval The topic structure for MWI messages
- * \retval NULL if it has not been allocated
- * \since 12
- */
-struct stasis_topic *ast_mwi_topic_all(void);
-
-/*!
- * \brief Get the \ref stasis topic for MWI messages on a unique ID
- * \param uniqueid The unique id for which to get the topic
- * \retval The topic structure for MWI messages for a given uniqueid
- * \retval NULL if it failed to be found or allocated
- * \since 12
- */
-struct stasis_topic *ast_mwi_topic(const char *uniqueid);
-
-/*!
- * \brief Get the \ref stasis caching topic for MWI messages
- * \retval The caching topic structure for MWI messages
- * \retval NULL if it has not been allocated
- * \since 12
- */
-struct stasis_topic *ast_mwi_topic_cached(void);
-
-/*!
- * \brief Backend cache for ast_mwi_topic_cached().
- * \retval Cache of \ref ast_mwi_state.
- */
-struct stasis_cache *ast_mwi_state_cache(void);
-
-/*!
- * \brief Get the \ref stasis message type for MWI messages
- * \retval The message type structure for MWI messages
- * \retval NULL on error
- * \since 12
- */
-struct stasis_message_type *ast_mwi_state_type(void);
-
-/*!
- * \brief Get the \ref stasis message type for voicemail application specific messages
- *
- * This message type exists for those messages a voicemail application may wish to send
- * that have no logical relationship with other voicemail applications. Voicemail apps
- * that use this message type must pass a \ref ast_mwi_blob. Any extraneous information
- * in the JSON blob must be packed as key/value pair tuples of strings.
- *
- * At least one key/value tuple must have a key value of "Event".
- *
- * \retval The \ref stasis_message_type for voicemail application specific messages
- * \retval NULL on error
- * \since 12
- */
-struct stasis_message_type *ast_mwi_vm_app_type(void);
-
 /*!
  * \brief Get the \ref stasis topic for queue messages
- * \retval The topic structure for queue messages
+ * \return The topic structure for queue messages
  * \retval NULL if it has not been allocated
  * \since 12
  */
@@ -1647,12 +1517,11 @@ struct stasis_topic *ast_queue_topic_all(void);
 /*!
  * \brief Get the \ref stasis topic for queue messages for a particular queue name
  * \param queuename The name for which to get the topic
- * \retval The topic structure for queue messages for a given name
+ * \return The topic structure for queue messages for a given name
  * \retval NULL if it failed to be found or allocated
  * \since 12
  */
 struct stasis_topic *ast_queue_topic(const char *queuename);
-/*! @} */
 
 /*!
  * \brief Initialize the application core
@@ -1662,7 +1531,6 @@ struct stasis_topic *ast_queue_topic(const char *queuename);
  */
 int app_init(void);
 
-#define AST_MAX_MAILBOX_UNIQUEID (AST_MAX_EXTENSION + AST_MAX_CONTEXT + 2)
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
